summaryrefslogtreecommitdiff
path: root/src/misc/dbg_helpers.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/misc/dbg_helpers.h')
-rw-r--r--src/misc/dbg_helpers.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/misc/dbg_helpers.h b/src/misc/dbg_helpers.h
index acc1437d0..2e2a1a7e9 100644
--- a/src/misc/dbg_helpers.h
+++ b/src/misc/dbg_helpers.h
@@ -155,8 +155,8 @@ struct DumpTarget {
{
static size_t type_id = ++LastTypeId();
- if (s == NULL) {
- /* No need to dump NULL struct. */
+ if (s == nullptr) {
+ /* No need to dump nullptr struct. */
WriteLine("%s = <null>", name);
return;
}